@@ -1,5 +1,5 @@
 /*
-    Document   : dash_plugin_news.js
+    Document   : dash_plugin_2x5_news.js
     Created on : Aug 29, 2013, 21:26:23 PM
     Author     : Artur Barseghyan (artur.barseghyan@gmail.com)
     Description:
